.. _installation:

Installation
============

You can install ``jupyterlite-xeus-python`` with ``pip``:

.. code::

    pip install jupyterlite jupyterlite-xeus-python

    # This should pick up the xeus-python kernel automatically
    jupyter lite build
